summaryrefslogtreecommitdiffstats
path: root/compatibility-client
diff options
context:
space:
mode:
Diffstat (limited to 'compatibility-client')
-rw-r--r--compatibility-client/src/main/java/com/vaadin/v7/client/ui/VOptionGroup.java25
-rw-r--r--compatibility-client/src/main/java/com/vaadin/v7/client/ui/VScrollTable.java4
-rw-r--r--compatibility-client/src/main/java/com/vaadin/v7/client/ui/calendar/schedule/CalendarEvent.java4
3 files changed, 17 insertions, 16 deletions
diff --git a/compatibility-client/src/main/java/com/vaadin/v7/client/ui/VScrollTable.java b/compatibility-client/src/main/java/com/vaadin/v7/client/ui/VScrollTable.java
index 751f7cb3fe..af7b78b271 100644
--- a/compatibility-client/src/main/java/com/vaadin/v7/client/ui/VScrollTable.java
+++ b/compatibility-client/src/main/java/com/vaadin/v7/client/ui/VScrollTable.java
@@ -1375,7 +1375,7 @@ public class VScrollTable extends FlowPanel
/** For internal use only. May be removed or replaced in the future. */
public void resizeSortedColumnForSortIndicator() {
// Force recalculation of the captionContainer element inside the header
- // cell to accomodate for the size of the sort arrow.
+ // cell to accommodate for the size of the sort arrow.
HeaderCell sortedHeader = tHead.getHeaderCell(sortColumn);
if (sortedHeader != null) {
// Mark header as sorted now. Any earlier marking would lead to
@@ -3679,7 +3679,7 @@ public class VScrollTable extends FlowPanel
}
if (col.hasAttribute("width") && !c.isResizing) {
- // Make sure to accomodate for the sort indicator if
+ // Make sure to accommodate for the sort indicator if
// necessary.
int width = col.getIntAttribute("width");
int widthWithoutAddedIndent = width;
diff --git a/compatibility-client/src/main/java/com/vaadin/v7/client/ui/calendar/schedule/CalendarEvent.java b/compatibility-client/src/main/java/com/vaadin/v7/client/ui/calendar/schedule/CalendarEvent.java
index d60aa7f6de..bc08421d4c 100644
--- a/compatibility-client/src/main/java/com/vaadin/v7/client/ui/calendar/schedule/CalendarEvent.java
+++ b/compatibility-client/src/main/java/com/vaadin/v7/client/ui/calendar/schedule/CalendarEvent.java
@@ -186,7 +186,7 @@ public class CalendarEvent {
/**
* Get the description of the event. The description is the text displayed
- * when hoovering over the event with the mouse
+ * when hovering over the event with the mouse
*
* @return
*/
@@ -196,7 +196,7 @@ public class CalendarEvent {
/**
* Set the description of the event. The description is the text displayed
- * when hoovering over the event with the mouse
+ * when hovering over the event with the mouse
*
* @param description
*/
diff --git a/compatibility-client/src/main/java/com/vaadin/v7/client/ui/VOptionGroup.java b/compatibility-client/src/main/java/com/vaadin/v7/client/ui/VOptionGroup.java
index 4abcc75f4d..dcca730f36 100644
--- a/compatibility-client/src/main/java/com/vaadin/v7/client/ui/VOptionGroup.java
+++ b/compatibility-client/src/main/java/com/vaadin/v7/client/ui/VOptionGroup.java
@@ -83,9 +83,9 @@ public class VOptionGroup extends VOptionGroupBase
* optiongroup: if a control inside this optiongroup gains focus right after
* blur of another control inside this optiongroup (meaning: if onFocus
* fires after onBlur has fired), the blur and focus won't be sent to the
* server side as only a focus change inside this optiongroup occured
*/
- private boolean blurOccured = false;
+ private boolean blurOccurred = false;
/** For internal use only. May be removed or replaced in the future. */
public boolean htmlContentAllowed = false;
@@ -276,35 +276,36 @@ public class VOptionGroup extends VOptionGroupBase
@Override
public void onFocus(FocusEvent arg0) {
- if (!blurOccured) {
- // no blur occured before this focus event
+ if (!blurOccurred) {
+ // no blur occurred before this focus event
// panel was blurred => fire the event to the server side if
// requested by server side
if (sendFocusEvents) {
client.updateVariable(paintableId, EventId.FOCUS, "", true);
}
} else {
// blur occured before this focus event
// another control inside the panel (checkbox / radio box) was
- // blurred => do not fire the focus and set blurOccured to false, so
+ // blurred => do not fire the focus and set blurOccurred to false,
+ // so
// blur will not be fired, too
- blurOccured = false;
+ blurOccurred = false;
}
}
@Override
public void onBlur(BlurEvent arg0) {
- blurOccured = true;
+ blurOccurred = true;
if (sendBlurEvents) {
Scheduler.get().scheduleDeferred(new Command() {
@Override
public void execute() {
- // check whether blurOccured still is true and then send the
- // event out to the server
- if (blurOccured) {
+ // check whether blurOccurred still is true and then send
+ // the event out to the server
+ if (blurOccurred) {
client.updateVariable(paintableId, EventId.BLUR, "",
true);
- blurOccured = false;
+ blurOccurred = false;
}
}
});
@@ -83,9 +83,9 @@ public class VOptionGroup extends VOptionGroupBase
* blur of another control inside this optiongroup (meaning: if onFocus
* fires after onBlur has fired), the blur and focus won't be sent to the
- * server side as only a focus change inside this optiongroup occured
+ * server side as only a focus change inside this optiongroup occurred
*/
@@ -276,35 +276,36 @@ public class VOptionGroup extends VOptionGroupBase
}
} else {
- // blur occured before this focus event
+ // blur occurred before this focus event
// another control inside the panel (checkbox / radio box) was